pub enum MetadataValueKindKey {
Show 24 variants
ForceAlign,
BitFlags,
CsharpPartial,
Private,
NativeType,
NativeTypePackName,
OriginalOrder,
Required,
Deprecated,
Key,
Shared,
NestedFlatbuffer,
Id,
Hash,
CppType,
CppPtrType,
CppPtrTypeGet,
CppStrType,
CppStrFlexCtor,
NativeInline,
NativeDefault,
Flexbuffer,
Streaming,
Idempotent,
}
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.