pub struct Schema {
pub file_id: FileId,
pub native_includes: Vec<StringLiteral>,
pub includes: Vec<StringLiteral>,
pub namespace: Option<(Span, NamespacePath)>,
pub root_type: Option<(Span, Type)>,
pub file_extension: Option<(Span, StringLiteral)>,
pub file_identifier: Option<(Span, StringLiteral)>,
pub attributes: Vec<Attribute>,
pub type_declarations: IndexMap<RawIdentifier, Declaration>,
pub errors_seen: Cell<ErrorKind>,
}
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.