pub enum ResolvedType<'a, B: ?Sized + Backend> {
Struct(&'a Struct, &'a B::StructInfo, RelativeNamespace<'a, B>),
Table(&'a Table, &'a B::TableInfo, RelativeNamespace<'a, B>),
Enum(&'a Enum, &'a B::EnumInfo, RelativeNamespace<'a, B>, &'a [B::EnumVariantInfo]),
Union(&'a Union, &'a B::UnionInfo, RelativeNamespace<'a, B>),
Vector(Box<ResolvedType<'a, B>>),
Array(Box<ResolvedType<'a, B>>, u32),
String,
Bool,
Integer(IntegerType),
Float(FloatType),
}
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.